package internal

import (
	"context"
	"encoding/json"
	"gitea.cdlsxd.cn/sdk/plugin/proto"
	"plugins/union_pay_redpack/internal/po"
)

// 插件通信信息,若不对应则会报错panic
const (
	Tag         = "union_pay_redpack"
	Version     = 1
	CookieKey   = "union_pay_redpack"
	CookieValue = "union_pay_redpack"
)

const baseUri = "https://openapi.unionpay.com"

const (
	orderMethod    = "/upapi/mkt/pnt/pntAcquire/v1"
	orderBizMethod = "mkt.pnt.pntAcquire.v1"
)

const (
	queryMethod    = "/upapi/mkt/pnt/pntAcqQuery/v1"
	queryBizMethod = "mkt.pnt.pntAcqQuery.v1"
)

type UnionPayCpnService struct{}

func (p *UnionPayCpnService) Order(ctx context.Context, request *proto.OrderRequest) (*proto.OrderResponse, error) {
	c, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	req, err := c.orderReq(request)
	if err != nil {
		return nil, err
	}
	if err = req.Validate(); err != nil {
		return nil, err
	}

	_, bodyBytes, err := c.Request(ctx, req, orderMethod, orderBizMethod)
	if err != nil {
		return nil, err
	}

	var response po.OrderResp
	if err = json.Unmarshal(bodyBytes, &response); err != nil {
		return nil, proto.ErrorResponseFail(err.Error())
	}

	return orderResp(request, response), nil
}

func (p *UnionPayCpnService) Query(ctx context.Context, request *proto.QueryRequest) (*proto.QueryResponse, error) {
	c, err := transConfig(request.Config)
	if err != nil {
		return nil, err
	}
	req, err := c.queryReq(request, c.ChNlId)
	if err != nil {
		return nil, err
	}
	if err = req.Validate(); err != nil {
		return nil, err
	}

	_, bodyBytes, err := c.Request(ctx, req, queryMethod, queryBizMethod)
	if err != nil {
		return nil, err
	}

	var response po.QueryResp
	if err = json.Unmarshal(bodyBytes, &response); err != nil {
		return nil, proto.ErrorResponseFail(err.Error())
	}

	return queryResp(request, response), nil
}

func (p *UnionPayCpnService) Notify(_ context.Context, _ *proto.NotifyRequest) (*proto.NotifyResponse, error) {
	return notifyResp(), nil
}
